==> mediawiki-1.12.1.tar.gz: mediawiki-1.12.1/languages/messages/MessagesArn.php <==
<?php
/** Araucanian (Mapudungun)
 *
 * @ingroup Language
 * @file
 *
 * @author Clerc
 * @author Lin linao
 * @author Poquil
 */

$fallback = 'es';

$messages = array(
# User preference toggles
'tog-editondblclick' => 'Wirin pakina epu klik mew (JavaScript)',

'underline-always' => 'Rumel',
'underline-never'  => 'Turpu',

# Dates
'sunday'        => 'Domingku',
'monday'        => 'Lune',
'tuesday'       => 'Marte',
'wednesday'     => 'Mierkole',
'thursday'      => 'Kuefe',
'friday'        => 'Fierne',
'saturday'      => 'Safado',
'sun'           => 'dom',
'mon'           => 'lun',
'tue'           => 'mar',
'wed'           => 'mie',
'thu'           => 'kue',
'fri'           => 'fie',
'sat'           => 'saf',
'january'       => 'eneru küyeṉ',
'february'      => 'fewreru küyeṉ',
'march'         => 'marsu küyeṉ',
'april'         => 'afril küyeṉ',
'may_long'      => 'mayu küyeṉ',
'june'          => 'kuniu küyeṉ',
'july'          => 'kuliu küyeṉ',
'august'        => 'akostu küyeṉ',
'september'     => 'setiempüre küyeṉ',
'october'       => 'oktufüre küyeṉ',
'november'      => 'nofiempüre küyeṉ',
'december'      => 'disiempüre küyeṉ',
'january-gen'   => 'eneru küyeṉ',
'february-gen'  => 'fewreru küyeṉ',
'march-gen'     => 'marsu küyeṉ',
'april-gen'     => 'afril küyeṉ',
'may-gen'       => 'mayu küyeṉ',
'june-gen'      => 'kuniu küyeṉ',
'july-gen'      => 'kuliu küyeṉ',
'august-gen'    => 'akostu küyeṉ',
'september-gen' => 'setiempüre küyeṉ',
'october-gen'   => 'oktufüre küyeṉ',
'november-gen'  => 'nofiempüre küyeṉ',
'december-gen'  => 'disiempüre küyeṉ',
'jan'           => 'konlu eneru küyeṉ mew',
'feb'           => 'konlu fewreru küyeṉ mew',
'mar'           => 'konlu marsu küyeṉ mew',
'apr'           => 'konlu afril küyeṉ mew',
'may'           => 'konlu mayu küyeṉ',
'jun'           => 'konlu kuniu küyeṉ mew',
'jul'           => 'konlu kuliu küyeṉ mew',
'aug'           => 'konlu akostu küyeṉ mew',
'sep'           => 'konlu setiempüre küyeṉ mew',
'oct'           => 'konlu oktufüre küyeṉ mew',
'nov'           => 'konlu nofiempüre küyeṉ mew',
'dec'           => 'konlu disiempüre küyeṉ mew',

'qbfind'        => 'Kintun',
'qbedit'        => 'Wirin',
'qbmyoptions'   => 'tañi nütramkawe',
'moredotdotdot' => 'Doy...',
'mypage'        => 'tañi nütramkawe',
'mytalk'        => 'Tañi nütramkawe',
'anontalk'      => 'Tüfachi IP ñi nütramkawe',
'and'           => 'ka',

'returnto'         => 'Amutun $1 püle.',
'tagline'          => '{{SITENAME}} mew',
'help'             => 'Kellu',
'search'           => 'Kintun',
'searchbutton'     => 'Kintun',
'go'               => 'Amun',
'searcharticle'    => 'Amun',
'history'          => 'Pünon',
'history_short'    => 'Pünon',
'edit'             => 'Wirin',
'editthispage'     => 'Wirin tüfachi página',
'delete'           => 'Ñamümün',
'deletethispage'   => 'Ñamümün tüfachi pakina',
'protect'          => 'Elulan ñi wiriael',
'unprotect'        => 'Elun ñi wiriael',
'newpage'          => 'We Pakina',
'talkpage'         => 'Nütramkafinge tüfachi pakina',
'talkpagelinktext' => 'Nütramkawe',
'articlepage'      => 'adkintun artículo',
'talk'             => 'Nütramkawe',
'views'            => 'Pen',
'toolbox'          => 'Küdawpeyüm',
'userpage'         => 'adkintun página de usuario',
'projectpage'      => 'adkintun página meta',
'imagepage'        => 'Adkintun ad pakina',
'mediawikipage'    => 'adkintun página de mensaje',
'templatepage'     => 'adkintun página de plantilla',
'viewhelppage'     => 'adkintun página de ayuda',
'categorypage'     => 'adkintun página de categoría',
'viewtalkpage'     => 'Pen ti nütramkawe',
'otherlanguages'   => 'Kake dungun',
'jumpto'           => 'Amun:',
'jumptosearch'     => 'kintu',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'edithelp'     => 'Kellü wirin',
'edithelppage' => 'Help:Chum wiringekey pakina',
'helppage'     => 'Help:Kellu',
'mainpage'     => 'Wüne pakina',
'sitesupport'  => 'Elungechi',

'ok'                      => 'Feley may',
'youhavenewmessages'      => 'Elungeymi $1 ($2).',
'newmessageslink'         => 'we dungu',
'youhavenewmessagesmulti' => 'Elungeymi we dungu $1 mew.',
'editsection'             => 'wirin',
'editold'                 => 'wirin',
'showtoc'                 => 'pengelün',
'hidetoc'                 => 'ellkan',
'viewdeleted'             => 'Küpaadkintuymi $1 am?',
'restorelink'             => '{{PLURAL:$1|kiñe wirin ñamümgün|$1 wirin ñamümün}}',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-main'      => 'pakina',
'nstab-user'      => 'Lludüchi',
'nstab-special'   => 'Kangelu',
'nstab-mediawiki' => 'Dungu',
'nstab-help'      => 'Kelluwe',

# General errors
'filedeleteerror' => 'Pepiñamümüngelay "$1".',
'filenotfound'    => 'Pepipelafuy "$1".',
'badtitle'        => 'Nornongey ta üy',

# Login and logout pages
'loginpagetitle'     => 'Konün',
'yourname'           => 'Tami lludüchi üy',
'yourpassword'       => 'Tami kondungu',
'login'              => 'Konün',
'userlogin'          => 'Konün',
'logout'             => 'Tripan',
'userlogout'         => 'Tripan',
'notloggedin'        => 'Petu konlaymi.',
'nologin'            => 'Nielaymi kiñe lludüwe? $1.',
'nologinlink'        => 'Dewmafinge',
'gotaccountlink'     => 'Konün',
'yourrealname'       => 'Tami mupiñ üy *',
'yourlanguage'       => 'Dungun:',
'loginlanguagelabel' => 'Dungun: $1',

# Edit pages
'subject'            => 'Dungu/üy',
'minoredit'          => 'Tüfachi ta kiñe pichi wirin',
'watchthis'          => 'Llaytun tüfachi pakina',
'preview'            => 'Pen chum müley',
'showpreview'        => 'Pen chum müley',
'loginreqlink'       => 'Koni',
'newarticle'         => '(We)',
'editing'            => 'Wirimekey $1',
'editingcomment'     => 'Wirin $1 (Dungu)',
'yourtext'           => 'Tami wirin',
'template-protected' => '(Ngünaytun)',

# History pages
'page_first'   => 'wünen',
'deletedrev'   => '[ñamümüngelu]',
'historyempty' => '(welli)',

# Revision feed
'history-feed-item-nocomment' => '$1 $2 mew', # user at time

# Revision deletion
'rev-delundel' => 'pengelün/ellkan',

# Diffs
'lineno'   => 'Wirin $1:',
'editundo' => 'wüñoeltun',

# Search results
'viewprevnext' => 'Pen ($1) ($2) ($3).',
'powersearch'  => 'Kintun',

# Preferences page
'prefs-edits'       => 'Rakin Wirin:',
'prefsnologin'      => 'Mülelay Konün',
'textboxsize'       => 'Wirin',
'searchresultshead' => 'Kintun',

# Groups
'group'       => 'Kisuwen:',
'group-sysop' => 'Pu ngünefe',
'group-all'   => '(kom pu che)',

# User rights log
'rightsnone' => 'chemnorume',

# Recent changes
'rcshowhideminor'                   => '$1 wirin pichi',
'rcshowhidemine'                    => '$1 tañi wirin',
'hist'                              => 'Püno',
'hide'                              => 'Ellkan',
'show'                              => 'pengelün',
'minoreditletter'                   => 'p',
'newpageletter'                     => 'W',
'number_of_watching_users_pageview' => '[$1 {{PLURAL:$1|Lludüchi|Lludüchi}} wiñamüy]',

# Upload
'uploadnologin'   => 'Petu konlaymi',
'watchthisupload' => 'Llaytun tüfachi pakina',

'nolicense' => 'Chemnorume dullinnongey',

# Image list
'ilsubmit'           => 'Kintu',
'imgdelete'          => 'ñam',
'filehist-deleteall' => 'kom ñamümün',
'filehist-deleteone' => 'ñamümün tüfa',
'filehist-user'      => 'Lludüchi',
'imagelist_name'     => 'Üy',
'imagelist_user'     => 'Lludüchi',

# File deletion
'filedelete'         => '$1 ñamümün',
'filedelete-intro'   => "Ñamümmekeymi '''[[Media:$1|$1]]'''.",
'filedelete-submit'  => 'Ñamümün',
'filedelete-success' => "'''$1''' ñamümngey.",

# Unused templates
'unusedtemplateswlh' => "Kake ''enlase''",

'brokenredirects-edit'   => '(wirin)',
'brokenredirects-delete' => '(ñamümün)',

'withoutinterwiki-submit' => 'Pengelün',

# Miscellaneous special pages
'nbytes'            => '$1 {{PLURAL:$1|byte|bytes}}',
'nviews'            => '$1 {{PLURAL:$1|pen|pen}}',
'allpages'          => 'Kakelu pakina',
'shortpages'        => 'Pichi pakina',
'newpages'          => 'We pakina',
'newpages-username' => 'Güy lludüchi',
'move'              => 'Wiñamün',
'movethispage'      => 'Nengümün tüfachi pakina',

# Book sources
'booksources-go' => 'Amun',

# Special:Log
'specialloguserlabel'  => 'Lludüchi:',
'speciallogtitlelabel' => 'Üy:',
'log-search-submit'    => 'Amun',

# Special:Allpages
'allarticles'    => 'Fill pakina',
'allpagesnext'   => 'Inan',
'allpagessubmit' => 'Pengelün',

# Special:Listusers
'listusers-submit' => 'Pengelün',

# E-mail user
'emailsubject' => 'Dungu',
'emailmessage' => 'Dungu',
'emailsend'    => 'Werkün',

# Watchlist
'watchnologin'         => 'Petu konlaymi',
'watch'                => 'Llaytun',
'watchthispage'        => 'Llaytun tüfachi pakina',
'unwatch'              => 'Llaytuwelan',
'unwatchthispage'      => 'Llaytuwelan',
'notanarticle'         => 'Ngelay kiñe pakina',
'watchlist-show-own'   => 'Nülan ñi wirin',
'watchlist-hide-own'   => 'Ellkan ñi wirin',
'watchlist-show-minor' => 'Nülan pichi wirin',
'watchlist-hide-minor' => 'Ellkan wirin pichi',

'enotif_newpagetext'           => 'Tüfachi ta we pakina',
'enotif_impersonal_salutation' => '{{SITENAME}} lludüchi',
'created'                      => 'Llituy',

# Delete/protect/revert
'deletepage'              => 'Ñamümün tüfachi pakina',
'delete-confirm'          => 'Ñamümüngelu "$1"',
'delete-legend'           => 'Ñamümün',
'deletedarticle'          => '«[[$1]]» Ñamümün',
'protectexpiry'           => 'Afi:',
'protect-level-sysop'     => 'Pu ngünefe müṯen',
'protect-summary-cascade' => 'Trayengko',

# Restrictions (nouns)
'restriction-edit'   => 'Pepiwelukay',
'restriction-move'   => 'Pepiwiñami',
'restriction-create' => 'Llitun',

# Undelete
'viewdeletedpage'        => 'Pen pakina ñamümüngelu',
'undelete-search-box'    => 'Kintun ñamümüngelu pakina',
'undelete-search-submit' => 'Kintun',

# Namespace form on various pages
'blanknamespace' => '(Wüne pakina)',

# Contributions
'month' => 'Küyeṉ:',
'year'  => 'Tripantu:',

'sp-contributions-submit' => 'Kintun',

# What links here
'whatlinkshere-page' => 'Pakina:',
'whatlinkshere-prev' => '{{PLURAL:$1|Pen chum müley|Pen chum müluey $1}}',

# Block/unblock
'ipbexpiry'          => 'Afi',
'ipbotheroption'     => 'Kakelu',
'ipblocklist-submit' => 'Kintun',
'expiringblock'      => 'afi $1',

# Move page
'movearticle'             => 'Nengümün pakina',
'newtitle'                => 'We üy püle',
'move-watch'              => 'Llaytun tüfachi pakina',
'movepagebtn'             => 'Nengümün pakina',
'movedto'                 => 'Nengümün',
'1movedto2'               => '[[$1]] wiñamngey [[$2]] püle',
'delete_and_move'         => 'Ñamümün ka nengümün',
'delete_and_move_confirm' => 'May, ñamümün pakina',

# Namespace 8 related
'allmessagesname' => 'Üy',

# Tooltip help for the actions
'tooltip-pt-userpage'   => 'Ñi pakina lludüchi',
'tooltip-pt-mytalk'     => 'Tañi nütramkawe',
'tooltip-pt-logout'     => 'Tripan',
'tooltip-ca-delete'     => 'Ñamümün tüfachi pakina',
'tooltip-ca-move'       => 'Nengümün tüfachi pakina',
'tooltip-search'        => 'Kintun tüfachi wiki mew',
'tooltip-p-logo'        => 'Wüne pakina',
'tooltip-ca-nstab-user' => 'Pen lludüchi pakina',
'tooltip-ca-nstab-help' => 'Pen kellupakina',

# Attribution
'siteuser'  => 'Lludüchi $1 {{SITENAME}}',
'others'    => 'fill',
'siteusers' => '{{PLURAL:$2|Lludüchi|Lludüchi}} $1 {{SITENAME}}',

# Spam protection
'listingcontinuesabbrev' => 'ramt.',

# Info page
'numedits'     => 'Rakin wirin (pakina): $1',
'numtalkedits' => 'Rakin wirin (pakina nütramkawe): $1',

# Patrol log
'patrol-log-diff' => 'ng$1',

# Video information, used by Language::formatTimePeriod() to format lengths in the above messages
'hours-abbrev' => 'o',

# EXIF tags
'exif-exposuretime-format' => '$1 sek ($2)',

'exif-meteringmode-0'   => 'Kimnoelchi',
'exif-meteringmode-255' => 'Kakelu',

'exif-lightsource-0' => 'Kimnoelchi',

'exif-gaincontrol-0' => 'Chemnorume',

'exif-contrast-2' => 'Yafü',

'exif-sharpness-2' => 'Yafü',

'exif-subjectdistancerange-0' => 'Kimnoelchi',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => 'kom',
'imagelistall'     => 'kom',
'watchlistall2'    => 'Fill',
'namespacesall'    => 'kom',
'monthsall'        => '(kom)',

# Trackbacks
'trackbackremove' => ' ([$1 Ñamümün])',

# action=purge
'confirm_purge_button' => 'Feley may',

# Multipage image navigation
'imgmultigo' => 'Amun!',

# Table pager
'table_pager_limit_submit' => 'Amun',

# Size units
'size-bytes'     => '$1 b',
'size-kilobytes' => '$1 Kb',
'size-megabytes' => '$1 Mb',
'size-gigabytes' => '$1 Gb',

# Special:Version
'version-other' => 'Kakelu',

);

==> mediawiki-1.13.0rc2.tar.gz: mediawiki-1.13.0rc2/languages/messages/MessagesArn.php <==
<?php
/** Araucanian (Mapudungun)
 *
 * @ingroup Language
 * @file
 *
 * @author Clerc
 * @author Lin linao
 * @author Poquil
 */

$fallback = 'es';

$messages = array(
# User preference toggles
'tog-editondblclick' => 'Wirin pakina epu klik mew (JavaScript)',

'underline-always' => 'Rumel',
'underline-never'  => 'Turpu',

# Dates
'sunday'        => 'Domingku',
'monday'        => 'Lune',
'tuesday'       => 'Marte',
'wednesday'     => 'Mierkole',
'thursday'      => 'Kuefe',
'friday'        => 'Fierne',
'saturday'      => 'Safado',
'sun'           => 'dom',
'mon'           => 'lun',
'tue'           => 'mar',
'wed'           => 'mie',
'thu'           => 'kue',
'fri'           => 'fie',
'sat'           => 'saf',
'january'       => 'eneru küyeṉ',
'february'      => 'fewreru küyeṉ',
'march'         => 'marsu küyeṉ',
'april'         => 'afril küyeṉ',
'may_long'      => 'mayu küyeṉ',
'june'          => 'kuniu küyeṉ',
'july'          => 'kuliu küyeṉ',
'august'        => 'akostu küyeṉ',
'september'     => 'setiempüre küyeṉ',
'october'       => 'oktufüre küyeṉ',
'november'      => 'nofiempüre küyeṉ',
'december'      => 'disiempüre küyeṉ',
'january-gen'   => 'eneru küyeṉ',
'february-gen'  => 'fewreru küyeṉ',
'march-gen'     => 'marsu küyeṉ',
'april-gen'     => 'afril küyeṉ',
'may-gen'       => 'mayu küyeṉ',
'june-gen'      => 'kuniu küyeṉ',
'july-gen'      => 'kuliu küyeṉ',
'august-gen'    => 'akostu küyeṉ',
'september-gen' => 'setiempüre küyeṉ',
'october-gen'   => 'oktufüre küyeṉ',
'november-gen'  => 'nofiempüre küyeṉ',
'december-gen'  => 'disiempüre küyeṉ',
'jan'           => 'konlu eneru küyeṉ mew',
'feb'           => 'konlu fewreru küyeṉ mew',
'mar'           => 'konlu marsu küyeṉ mew',
'apr'           => 'konlu afril küyeṉ mew',
'may'           => 'konlu mayu küyeṉ',
'jun'           => 'konlu kuniu küyeṉ mew',
'jul'           => 'konlu kuliu küyeṉ mew',
'aug'           => 'konlu akostu küyeṉ mew',
'sep'           => 'konlu setiempüre küyeṉ mew',
'oct'           => 'konlu oktufüre küyeṉ mew',
'nov'           => 'konlu nofiempüre küyeṉ mew',
'dec'           => 'konlu disiempüre küyeṉ mew',

# Categories related messages
'listingcontinuesabbrev' => 'ramt.',

'qbfind'        => 'Kintun',
'qbedit'        => 'Wirin',
'qbmyoptions'   => 'tañi nütramkawe',
'moredotdotdot' => 'Doy...',
'mypage'        => 'tañi nütramkawe',
'mytalk'        => 'Tañi nütramkawe',
'and'           => 'ka',

'returnto'         => 'Amutun $1 püle.',
'tagline'          => '{{SITENAME}} mew',
'help'             => 'Kellu',
'search'           => 'Kintun',
'searchbutton'     => 'Kintun',
'go'               => 'Amun',
'searcharticle'    => 'Amun',
'history'          => 'Pünon',
'history_short'    => 'Pünon',
'edit'             => 'Wirin',
'create'           => 'Llitun',
'editthispage'     => 'Wirin tüfachi página',
'delete'           => 'Ñamümün',
'protect'          => 'Elulan ñi wiriael',
'unprotect'        => 'Elun ñi wiriael',
'talkpage'         => 'Nütramkafinge tüfachi pakina',
'talkpagelinktext' => 'Nütramkawe',
'articlepage'      => 'adkintun artículo',
'talk'             => 'Nütramkawe',
'toolbox'          => 'Küdawpeyüm',
'userpage'         => 'adkintun página de usuario',
'projectpage'      => 'adkintun página meta',
'imagepage'        => 'adkintun página de imagen',
'mediawikipage'    => 'adkintun página de mensaje',
'templatepage'     => 'adkintun página de plantilla',
'viewhelppage'     => 'adkintun página de ayuda',
'categorypage'     => 'adkintun página de categoría',
'viewtalkpage'     => 'Pen ti nütramkawe',
'otherlanguages'   => 'Kake dungun',
'jumpto'           => 'Amun:',
'jumptosearch'     => 'kintu',

# All link text and link target definitions of links into project namespace that get used by other message strings, with the exception of user group pages (see grouppage) and the disambiguation template definition (see disambiguations).
'edithelppage' => 'Help:Chum wiringekey pakina',
'helppage'     => 'Help:Kellu',

'ok'                      => 'Feley may',
'youhavenewmessages'      => 'Elungeymi $1 ($2).',
'newmessageslink'         => 'we dungu',
'youhavenewmessagesmulti' => 'Elungeymi we dungu $1 mew.',
'editsection'             => 'wirin',
'editold'                 => 'wirin',
'showtoc'                 => 'pengelün',
'hidetoc'                 => 'ellkan',
'viewdeleted'             => 'Küpaadkintuymi $1 am?',

# Short words for each namespace, by default used in the namespace tab in monobook
'nstab-user'      => 'Lludüchi',
'nstab-special'   => 'Kangelu',
'nstab-mediawiki' => 'Dungu',
'nstab-help'      => 'Kelluwe',

# General errors
'filedeleteerror' => 'Pepiñamümüngelay "$1".',
'filenotfound'    => 'Pepipelafuy "$1".',
'badtitle'        => 'Nornongey ta üy',

# Login and logout pages
'loginpagetitle'          => 'Konün',
'yourname'                => 'Tami lludüchi üy',
'yourpassword'            => 'Tami kondungu',
'login'                   => 'Konün',
'nav-login-createaccount' => 'Registrarse/Konün',
'userlogin'               => 'Konün',
'logout'                  => 'Tripan',
'userlogout'              => 'Tripan',
'notloggedin'             => 'Petu konlaymi.',
'nologin'                 => 'Nielaymi kiñe lludüwe? $1.',
'nologinlink'             => 'Dewmafinge',
'gotaccountlink'          => 'Konün',
'yourrealname'            => 'Tami mupiñ üy *',
'yourlanguage'            => 'Dungun:',
'loginlanguagelabel'      => 'Dungun: $1',

# Edit pages
'subject'    => 'Dungu/üy',
'newarticle' => '(We)',
'editing'    => 'Wirimekey $1',
'yourtext'   => 'Tami wirin',

# History pages
'page_first'   => 'wünen',
'historyempty' => '(welli)',

# Revision feed
'history-feed-item-nocomment' => '$1 $2 mew', # user at time

# Revision deletion
'rev-delundel' => 'pengelün/ellkan',

# Diffs
'lineno'   => 'Wirin $1:',
'editundo' => 'wüñoeltun',

# Search results
'viewprevnext'          => 'Pen ($1) ($2) ($3).',
'search-interwiki-more' => '(Doy)',
'powersearch'           => 'Kintu',

# Groups
'group'       => 'Kisuwen:',
'group-sysop' => 'Pu ngünefe',
'group-all'   => '(kom pu che)',

# User rights log
'rightsnone' => 'chemnorume',

# Recent changes
'hide'            => 'Ellkan',
'minoreditletter' => 'p',
'newpageletter'   => 'W',

'nolicense' => 'Chemnorume dullinnongey',

# Special:ImageList
'imagelist_name' => 'Üy',

# Image description page
'filehist-deleteall' => 'kom ñamümün',
'filehist-deleteone' => 'tüfa ñamümün',

# File deletion
'filedelete'         => '$1 ñamümün',
'filedelete-intro'   => "Ñamümmekeymi '''[[Media:$1|$1]]'''.",
'filedelete-submit'  => 'Ñamümün',
'filedelete-success' => "'''$1''' ñamümngey.",

'brokenredirects-edit'   => '(wirin)',
'brokenredirects-delete' => '(ñamümün)',

'withoutinterwiki-submit' => 'Pengelün',

# Miscellaneous special pages
'move' => 'Wiñamün',

# Book sources
'booksources-go' => 'Amun',

# Special:Log
'speciallogtitlelabel' => 'Üy:',
'log-search-submit'    => 'Amun',

# Special:AllPages
'allpagesnext'   => 'Inan',
'allpagessubmit' => 'Pengelün',

# Special:ListUsers
'listusers-submit' => 'Pengelün',

# E-mail user
'emailsubject' => 'Dungu',
'emailsend'    => 'Werkün',

# Watchlist
'watch'           => 'Llaytun',
'unwatch'         => 'Llaytuwelan',
'unwatchthispage' => 'Llaytuwelan',

# Delete/protect/revert
'protectexpiry'       => 'Afi:',
'protect-level-sysop' => 'Pu ngünefe müṯen',

# Restrictions (nouns)
'restriction-edit' => 'Pepiwelukay',
'restriction-move' => 'Pepiwiñami',

# Undelete
'undelete-search-submit' => 'Kintun',

# Contributions
'month' => 'Küyeṉ:',
'year'  => 'Tripantu:',

'sp-contributions-submit' => 'Kintun',

# Block/unblock
'ipbexpiry'          => 'Afi',
'ipblocklist-submit' => 'Kintun',
'expiringblock'      => 'afi $1',

# Move page
'newtitle'  => 'We üy püle',
'1movedto2' => '[[$1]] wiñamngey [[$2]] püle',

# Namespace 8 related
'allmessagesname' => 'Üy',

# Tooltip help for the actions
'tooltip-pt-mytalk' => 'Tañi nütramkawe',
'tooltip-pt-logout' => 'Tripan',

# Patrol log
'patrol-log-diff' => 'ng$1',

# Special:NewImages
'ilsubmit' => 'Kintu',

# Video information, used by Language::formatTimePeriod() to format lengths in the above messages
'hours-abbrev' => 'o',

# EXIF tags
'exif-exposuretime-format' => '$1 sek ($2)',

'exif-meteringmode-0' => 'Kimnoelchi',

'exif-lightsource-0' => 'Kimnoelchi',

'exif-gaincontrol-0' => 'Chemnorume',

'exif-subjectdistancerange-0' => 'Kimnoelchi',

# 'all' in various places, this might be different for inflected languages
'recentchangesall' => 'kom',
'imagelistall'     => 'kom',
'namespacesall'    => 'kom',
'monthsall'        => '(kom)',

# action=purge
'confirm_purge_button' => 'Feley may',

# Multipage image navigation
'imgmultigo' => 'Amun!',

# Table pager
'table_pager_limit_submit' => 'Amun',

# Size units
'size-bytes'     => '$1 b',
'size-kilobytes' => '$1 Kb',
'size-megabytes' => '$1 Mb',
'size-gigabytes' => '$1 Gb',

# Special:SpecialPages
'specialpages-group-login' => 'Konün',

);
